@@ -117,8 +117,6 @@ def _get_html(uri:AbsoluteURI) -> Union[HTML,XHTML]:
         # so we'll bail out here.
         raise UnrecognizedContentType(ct, uri)
 
-    return (page.content, resolved_url)
-
 def _parse_html(html:Union[HTML,XHTML]) -> Signposting:
     soup = BeautifulSoup(html, 'html.parser', 
         # Ignore any other elements to reduce chance of parse errors
@@ -129,6 +127,7 @@ def _parse_html(html:Union[HTML,XHTML]) -> Signposting:
             # Ensure all filters are in lower case and known
             url = link.get("href")
             if not url:
+                warnings.warn("Invalid <link> element, missing href attribute: %s" % link)
                 continue
             type = link.get("type")
             profiles = link.get("profile")
